/* src/imginfo.h.  Generated by configure.  */
/*
 *                       Written by JoungKyun.Kim
 *            Copyright (c) 2011 JoungKyun.Kim <http://oops.org>
 *
 * -----------------------------------------------------------------------------
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *     * Neither the name of JoungKyun.Kim nor the url of oops.org
 *       nor the names of their contributors may be used to endorse or
 *       promote products derived from this software without specific prior
 *       written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * -----------------------------------------------------------------------------
 * This file is part of libimginfo.
 */

/*
 * $Id: imginfo.h.in 82 2011-05-01 15:18:55Z oops $
 */

/**
 * @file	imginfo.h
 * @brief	libimginfo header file
 *
 * @author	김정균 <http://oops.org>
 * $Date: 2011-05-02 00:18:55 +0900 (월, 02  5월 2011) $
 * $Revision: 82 $
 * @attention	Copyright (c) 2011 JoungKyun.Kim all rights reserved.
 */

#ifndef IMGINFO_H
#define IMGINFO_H

#ifndef COMMON_H
#define IMG_EXTERN extern
#else
#define IMG_EXTERN
#endif

#ifndef HAVE_STDBOOL_H
	#define HAVE_STDBOOL_H 1
#endif

#ifdef HAVE_STDBOOL_H
	#include <stdbool.h>
#else
	#ifndef _STDBOOL_H
		#define _STDBOOL_H
		#ifndef __cplusplus

			#define bool    _Bool
			#define true    1
			#define false   0

		#else /* __cplusplus */

			/* Supporting <stdbool.h> in C++ is a GCC extension.  */
			#define _Bool   bool
			#define bool    bool
			#define false   false
			#define true    true

		#endif /* __cplusplus */

		/* Signal that all the definitions are present.  */
		#define __bool_true_false_are_defined   1
	#endif
#endif

#include <sys/types.h>
#include <stdint.h>

# ifdef __cplusplus
extern "C"
{
# endif

#ifndef null
	#define null NULL
#endif

typedef unsigned char UChar; //!< unsigned char
typedef const char CChar;    //!< const char
typedef uint16_t UShort;     //!< unsigned short
typedef uint32_t UInt;       //!< unsigned int

//! Image 정보를 담고 있는 구조체
typedef struct {
	UInt width;              //!< Image 넓이
	UInt height;             //!< Image 높이
	UShort bits;             //!< Image 비트
	UShort channels;         //!< Image 채널
	UShort type;             //!< Image content-type
} ImgInfo;

//! Images 타입 정의
enum imginfo_type {
	IMGINFO_NULL,
	IMGINFO_JPEG,             //!< JEPG 형식
	IMGINFO_PNG,              //!< PNG 형식
	IMGINFO_GIF               //!< GIF 형식
};

/*
 * public API
 */
IMG_EXTERN size_t imginfo_ver (void);
IMG_EXTERN ImgInfo imginfo (const char *path);

# ifdef __cplusplus
}
# endif
#endif

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
