dnl 
dnl                       Written by JoungKyun.Kim
dnl            Copyright (c) 2011 JoungKyun.Kim <http://oops.org>
dnl 
dnl ----------------------------------------------------------------------------
dnl Redistribution and use in source and binary forms, with or without
dnl modification, are permitted provided that the following conditions are met:
dnl 
dnl     * Redistributions of source code must retain the above copyright notice,
dnl       this list of conditions and the following disclaimer.
dnl 
dnl     * Redistributions in binary form must reproduce the above copyright
dnl       notice, this list of conditions and the following disclaimer in the
dnl       documentation and/or other materials provided with the distribution.
dnl 
dnl     * Neither the name of JoungKyun.Kim nor the url of oops.org
dnl       nor the names of their contributors may be used to endorse or
dnl       promote products derived from this software without specific prior
dnl       written permission.
dnl 
dnl THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
dnl AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
dnl IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
dnl ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
dnl LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
dnl CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
dnl SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
dnl INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
dnl CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
dnl ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
dnl POSSIBILITY OF SUCH DAMAGE.
dnl ----------------------------------------------------------------------------
dnl  This file is part of libimginfo.
dnl
dnl  $Id: imginfo.m4.in 82 2011-05-01 15:18:55Z oops $
dnl 

AC_DEFUN([AX_IMGINFO_WITH],
[
	if test "x$with_imginfo" != "x"; then
		if test "x$with_imginfo" = "xyes"; then
			imginfoconfig="/usr/bin/imginfo-config"
		else
			imginfoconfig="$with_imginfo"
		fi
	else
		imginfoconfig="/usr/bin/imginfo-config"
	fi

	AC_MSG_CHECKING(for imginfo-config path)
	if test ! -f "$imginfoconfig" || test ! -x "$imginfoconfig"; then
		if test $imginfo_check_failed -eq 1; then
			AC_MSG_ERROR(can't find $imginfoconfig)
		else
			imginfoconfig=
			AC_MSG_RESULT([not found])
		fi
	else
		AC_MSG_RESULT([$imginfoconfig])
	fi
])

AC_DEFUN([AX_IMGINFO_HEADER],
[
	#
	# imginfo header check
	#
	IMGINFO_INCLUDES="`$imginfoconfig --includes 2> /dev/null`"
	if test -z "$IMGINFO_INCLUDES"; then
		IMGINFO_INCLUDES="`$imginfoconfig --defs 2> /dev/null | sed 's/[[ ]]*-D[[^ ]]*//g'`"
	fi

	ret_cppflags=0
	for check_cppflags in $CPPFLAGS
	do
		test -z "$IMGINFO_INCLUDES" && break

		if test "$check_cppflags" = "$IMGINFO_INCLUDES"; then
			ret_cppflags=1
			break
		fi
	done
	test $ret_cppflags -eq 0 && CPPFLAGS="$IMGINFO_INCLUDES $CPPFLAGS"
	AC_CHECK_HEADERS(imginfo.h)
	if test "$ac_cv_header_imginfo_h" != "yes"; then
		AC_MSG_ERROR([You must need imginfo.h header file])
	fi
])

AC_DEFUN([AX_IMGINFO_LD],
[
	#
	# imginfo library check
	#
	IMGINFO_LDFLAGS="`$imginfoconfig --ldflags 2> /dev/null`"

	#
	# for compatibility
	#
	if test -z "$IMGINFO_LDFLAGS"; then
		IMGINFO_LDFLAGS="`$imginfoconfig --libs 2> /dev/null | sed 's/[[[:space:]]]*-l.*//g'`"
	fi

	imginfo_OLD_LDFLAGS="$LDFLAGS"
	LDFLAGS="$IMGINFO_LDFLAGS"
	AC_CHECK_LIB(
		imginfo, imginfo, [
			AC_DEFINE(
				[HAVE_LIBIMGINFO], 1,
				[Define to 1 if you have the `imginfo' library (-limginfo).])
			LIBS="`$imginfoconfig --libs 2> /dev/null` $LIBS"
		],[
			if test $imginfo_check_failed -eq 1; then
				AC_MSG_ERROR([Can't not found `imginfo' library (-limginfo)])
			fi
		]
	)
	LDFLAGS="$imginfo_OLD_LDFLAGS"

	ret_ldflags=0
	for check_ldflags in $LDFLAGS
	do
		test -z "$IMGINFO_LDFLAGS" && break

		if test "$check_ldflags" = "$IMGINFO_LDFLAGS"; then
			ret_ldflags=1
			break
		fi
	done

	test $ret_ldflags -eq 0 && LDFLAGS="$IMGINFO_LDFLAGS $LDFLAGS"
])

AC_DEFUN([AX_IMGINFO_LIBTOOL],
[
	#
	# imginfo library check
	#
	AC_MSG_CHECKING(for imginfo in -limginfo)

	IMGINFO_LIBS="`$imginfoconfig --link-libtool 2> /dev/null`"
	if test -z "$IMGINFO_LIBS"; then
		IMGINFO_LIBS="`$imginfoconfig --libs 2> /dev/null`"
	fi

	if test "x$IMGINFO_LIBS" = "x"; then
		AC_MSG_RESULT([no])
		if test $imginfo_check_failed -eq 1; then
			AC_MSG_ERROR([Can't not found imginfo libtool library (libimginfo.la)])
		fi
	else
		AC_MSG_RESULT([yes])
		LIBS="$IMGINFO_LIBS $LIBS"
		AC_DEFINE(
			[HAVE_LIBIMGINFO], 1,
			[Define to 1 if you have the `imginfo' library (-limginfo).])
	fi
])

dnl
dnl Usage AX_IMGINFO
dnl 	AX_IMGINFO([library type],[stop on failed])
dnl 		library type : ld or libtool
dnl 		stop on failed : 1 => stop, 0 => continue
dnl
dnl		AX_IMGINFO([library type])
dnl		AX_IMGINFO(1)
dnl
dnl 	no argument on AX_IMGINFO
dnl 		library type   = ld
dnl 		stop on failed = 0
dnl
AC_DEFUN([AX_IMGINFO],
[
	ax_imginfo_argc=$#
	imginfo_check_failed=0

	if test $ax_imginfo_argc -gt 0; then
		ax_imginfo_first_arg=$1
		ax_imginfo_second_arg=$2
	fi

	if test $ax_imginfo_argc -gt 0; then
		if test $ax_imginfo_argc -eq 2; then
			if test "$ax_imginfo_first_arg" = "libtool"; then
				imginfo_ld_mode="libtool"
			elif test "$ax_imginfo_first_arg" = "ld"; then
				imginfo_ld_mode="ld"
			else
				AC_MSG_ERROR([Unsupported link type on AX IMGINFO macro])
			fi

			if test $ax_imginfo_second_arg -eq 1; then
				imginfo_check_failed=1
			fi
		elif test $ax_imginfo_argc -eq 1; then
			if test "$ax_imginfo_first_arg" = "libtool"; then
				imginfo_ld_mode="libtool"
			elif test "$ax_imginfo_first_arg" = "ld"; then
				imginfo_ld_mode="ld"
			elif test $ax_imginfo_first_arg -eq 1 || test $ax_imginfo_first_arg -eq 0 ; then
				imginfo_check_failed=$ax_imginfo_first_arg
			else
				AC_MSG_ERROR([Unsupported argument value on AX IMGINFO macro])
			fi
		else
			AC_MSG_ERROR([So many arguments on AX IMGINFO macro])
		fi
	fi

	AC_ARG_WITH(imginfo,
		[  --with-imginfo=PATH     path of imginfo-config [[default: /usr/bin/imginfo-config]]])

	if test "x$with_imginfo" != "xno"; then
		AX_IMGINFO_WITH

		if test "$imginfo_ld_mode" = "libtool"; then
			AX_IMGINFO_LIBTOOL
		else
			AX_IMGINFO_LD
		fi
		AX_IMGINFO_HEADER
	else
		if test $imginfo_check_failed -eq 1; then
			AC_MSG_ERROR([--without-imginfo doesn't permit])
		fi
	fi
])
